@@ -54,6 +54,7 @@ function set-libraries-rel() {
 function set-libraries() {
   libffmpeg="libavformat-dev"
   libexif="libexif-dev"
+  jsoncpp="libjsoncpp-dev"
   libexiv2="libexiv2-dev"
   libpugixml="libpugixml-dev"
   libmatroska="libebml-dev libmatroska-dev"
@@ -76,10 +77,15 @@ function upload_to_repo() {
   install-deb-s3
 
   echo "${PKG_SIGNING_KEY}" | gpg --import
+  PRES_VERS='--no-preserve-versions'
+  if [[ "$1" == "debian" ]]; then
+      PRES_VERS='--preserve-versions'
+  fi
 
   deb-s3 upload \
     --bucket=gerbera \
     --prefix="${1}" \
+    ${PRES_VERS} \
     --codename="${lsb_codename}" \
     --arch="${deb_arch}" \
     --lock \
@@ -88,6 +94,18 @@ function upload_to_repo() {
     --secret-access-key="${DEB_UPLOAD_SECRET_ACCESS_KEY}" \
     --endpoint="${DEB_UPLOAD_ENDPOINT}" \
     "${deb_name}"
+
+  # Clean old debs after they are replaced above
+  if [[ "$1" != "debian" ]]; then
+    deb-s3 clean \
+      --bucket=gerbera \
+      --prefix="${1}" \
+      --codename="${lsb_codename}" \
+      --sign="${PKG_SIGNING_KEY_ID}" \
+      --access-key-id="${DEB_UPLOAD_ACCESS_KEY_ID}" \
+      --secret-access-key="${DEB_UPLOAD_SECRET_ACCESS_KEY}" \
+      --endpoint="${DEB_UPLOAD_ENDPOINT}"
+  fi
   echo "::endgroup::"
 }
 
@@ -182,6 +200,9 @@ if [[ ! -d "${BUILD_DIR}" ]]; then
       ${libmagic} \
       ${libmysqlclient} \
       ${libpugixml} \
+      ${jsoncpp} \
+      libsystemd-dev \
+      libicu-dev \
       libsqlite3-dev \
       uuid-dev
   sudo apt-get clean
@@ -193,6 +214,13 @@ if [[ ! -d "${BUILD_DIR}" ]]; then
   fi
   echo "::endgroup::"
 
+  WITH_POSTGRES="ON"
+  if [[ "${lsb_codename}" != "bionic" ]]; then
+    install-libpqxx static
+  else
+    WITH_POSTGRES="OFF"
+  fi
+
   if [[ "${my_sys}" == "HEAD" ]]; then
     install-googletest
     install-libexif
@@ -265,6 +293,7 @@ if [[ (! -f ${deb_name}) || "${my_sys}" == "HEAD" ]]; then
   echo "::group::Building gerbera"
   cmake "${ROOT_DIR}" --preset="${cmake_preset}" \
     -DWITH_SYSTEMD=${WITH_SYSTEMD} \
+    -DWITH_PGSQL=${WITH_POSTGRES} \
     -DBUILD_CHANGELOG=ON \
     -DCMAKE_INSTALL_PREFIX=/usr
   make "-j$(nproc)"
