@@ -21,7 +21,7 @@
     $Id$
 */
 
-/// @file box_layout.h
+/// @file config/result/box_layout.h
 /// @brief Definition of the BoxLayout class.
 
 #ifndef __BOXLAYOUT_H_
@@ -45,134 +45,174 @@ enum class AutoscanMediaMode;
 using EditHelperBoxLayout = EditHelper<BoxLayout>;
 using EditHelperBoxChain = EditHelper<BoxChain>;
 
-/// @brief Predefined box keys
-class BoxKeys {
-public:
-    static constexpr std::string_view root = "Root";
-    static constexpr std::string_view pcDirectory = "PCDirectory";
-    static constexpr std::string_view audioAllAlbums = "Audio/allAlbums";
-    static constexpr std::string_view audioAllArtists = "Audio/allArtists";
-    static constexpr std::string_view audioAll = "Audio/allAudio";
-    static constexpr std::string_view audioAllComposers = "Audio/allComposers";
-    static constexpr std::string_view audioAllDirectories = "Audio/allDirectories";
-    static constexpr std::string_view audioAllGenres = "Audio/allGenres";
-    static constexpr std::string_view audioAllSongs = "Audio/allSongs";
-    static constexpr std::string_view audioAllTracks = "Audio/allTracks";
-    static constexpr std::string_view audioAllYears = "Audio/allYears";
-    static constexpr std::string_view audioArtistChronology = "Audio/artistChronology";
-    static constexpr std::string_view audioRoot = "Audio/audioRoot";
+enum class BoxKeys {
+    root,
+    pcDirectory,
+    audioAllAlbums,
+    audioAllArtists,
+    audioAll,
+    audioAllComposers,
+    audioAllDirectories,
+    audioAllGenres,
+    audioAllSongs,
+    audioAllTracks,
+    audioAllYears,
+    audioArtistChronology,
+    audioRoot,
 
-    static constexpr std::string_view audioInitialAbc = "AudioInitial/abc";
-    static constexpr std::string_view audioInitialAllArtistTracks = "AudioInitial/allArtistTracks";
-    static constexpr std::string_view audioInitialAllBooks = "AudioInitial/allBooks";
-    static constexpr std::string_view audioInitialAudioBookRoot = "AudioInitial/audioBookRoot";
+    audioInitialAbc,
+    audioInitialAllArtistTracks,
+    audioInitialAllBooks,
+    audioInitialAudioBookRoot,
 
-    static constexpr std::string_view audioStructuredAllAlbums = "AudioStructured/allAlbums";
-    static constexpr std::string_view audioStructuredAllArtistTracks = "AudioStructured/allArtistTracks";
-    static constexpr std::string_view audioStructuredAllArtists = "AudioStructured/allArtists";
-    static constexpr std::string_view audioStructuredAllGenres = "AudioStructured/allGenres";
-    static constexpr std::string_view audioStructuredAllTracks = "AudioStructured/allTracks";
-    static constexpr std::string_view audioStructuredAllYears = "AudioStructured/allYears";
+    audioStructuredAllAlbums,
+    audioStructuredAllArtistTracks,
+    audioStructuredAllArtists,
+    audioStructuredAllGenres,
+    audioStructuredAllTracks,
+    audioStructuredAllYears,
 
-    static constexpr std::string_view videoAllDates = "Video/allDates";
-    static constexpr std::string_view videoAllDirectories = "Video/allDirectories";
-    static constexpr std::string_view videoAll = "Video/allVideo";
-    static constexpr std::string_view videoAllYears = "Video/allYears";
-    static constexpr std::string_view videoRoot = "Video/videoRoot";
-    static constexpr std::string_view videoUnknown = "Video/unknown";
+    videoAllDates,
+    videoAllDirectories,
+    videoAll,
+    videoAllYears,
+    videoRoot,
+    videoUnknown,
 
-    static constexpr std::string_view imageAllDates = "Image/allDates";
-    static constexpr std::string_view imageAllDirectories = "Image/allDirectories";
-    static constexpr std::string_view imageAll = "Image/allImages";
-    static constexpr std::string_view imageAllYears = "Image/allYears";
-    static constexpr std::string_view imageRoot = "Image/imageRoot";
-    static constexpr std::string_view imageUnknown = "Image/unknown";
+    imageAllDates,
+    imageAllDirectories,
+    imageAll,
+    imageAllYears,
+    imageRoot,
+    imageUnknown,
 
 #ifdef ONLINE_SERVICES
-    static constexpr std::string_view trailerAllGenres = "Trailer/allGenres";
-    static constexpr std::string_view trailerAll = "Trailer/allTrailers";
-    static constexpr std::string_view trailerPostDate = "Trailer/postDate";
-    static constexpr std::string_view trailerRelDate = "Trailer/relDate";
-    static constexpr std::string_view trailerRoot = "Trailer/trailerRoot";
-    static constexpr std::string_view trailerUnknown = "Trailer/unknown";
+    trailerAllGenres,
+    trailerAll,
+    trailerPostDate,
+    trailerRelDate,
+    trailerRoot,
+    trailerUnknown,
 #endif
 
-    static constexpr std::string_view playlistAll = "Playlist/allPlaylists";
-    static constexpr std::string_view playlistAllDirectories = "Playlist/allDirectories";
-    static constexpr std::string_view playlistRoot = "Playlist/playlistRoot";
+    playlistAll,
+    playlistAllDirectories,
+    playlistRoot,
+
+    Custom,
 };
 
 /// @brief Manager class for BoxLayout and BoxChain
 class BoxLayoutList : public EditHelperBoxLayout, public EditHelperBoxChain {
 public:
-    std::shared_ptr<BoxLayout> getKey(const std::string_view& key) const;
+    std::shared_ptr<BoxLayout> getKey(BoxKeys key) const;
 };
 
 /// @brief Define properties of a tree entry in virtual layout
 class BoxLayout : public Editable {
+    static const std::map<BoxKeys, std::string_view> boxKeys;
+
 public:
+    static std::string getBoxKey(BoxKeys bkey);
+    static BoxKeys getBoxKey(const std::string& key);
+
     BoxLayout() = default;
     ~BoxLayout() override = default;
     explicit BoxLayout(
-        const std::string_view& key,
+        BoxKeys bkey,
         std::string title,
         std::string objClass = UPNP_CLASS_CONTAINER,
         std::string upnpShortcut = "",
         std::string sortKey = "",
         bool enabled = true,
+        bool searchable = true,
         int size = 1)
-        : key(key)
+        : key(BoxLayout::getBoxKey(bkey))
         , title(std::move(title))
         , objClass(std::move(objClass))
         , upnpShortcut(std::move(upnpShortcut))
         , sortKey(std::move(sortKey))
         , enabled(enabled)
+        , searchable(searchable)
+        , size(size)
+    {
+    }
+    explicit BoxLayout(
+        std::string key,
+        std::string title,
+        std::string objClass = UPNP_CLASS_CONTAINER,
+        std::string upnpShortcut = "",
+        std::string sortKey = "",
+        bool enabled = true,
+        bool searchable = true,
+        int size = 1)
+        : key(std::move(key))
+        , title(std::move(title))
+        , objClass(std::move(objClass))
+        , upnpShortcut(std::move(upnpShortcut))
+        , sortKey(std::move(sortKey))
+        , enabled(enabled)
+        , searchable(searchable)
         , size(size)
     {
     }
 
     bool equals(const std::shared_ptr<BoxLayout>& other) { return this->key == other->key; }
 
+    /// @brief key for the box to be referenced in layouts
     void setKey(std::string key) { this->key = std::move(key); }
     std::string getKey() const { return key; }
 
+    /// @brief title string for the box
     void setTitle(std::string title) { this->title = std::move(title); }
     std::string getTitle() const { return title; }
 
+    /// @brief shortcut name for upnp shortcuts list
     void setUpnpShortcut(std::string upnpShortcut) { this->upnpShortcut = std::move(upnpShortcut); }
     std::string getUpnpShortcut() const { return upnpShortcut; }
 
+    /// @brief object class to be used for new containers
     void setClass(std::string objClass) { this->objClass = std::move(objClass); }
     std::string getClass() const { return objClass; }
 
+    /// @brief allow to disable boxes
     void setEnabled(bool enabled) { this->enabled = enabled; }
     bool getEnabled() const { return enabled; }
 
+    /// @brief allow to search for boxes
+    void setSearchable(bool searchable) { this->searchable = searchable; }
+    bool getSearchable() const { return searchable; }
+
+    /// @brief size value for the box, esp. in structured layout
     void setSize(int size) { this->size = size; }
     int getSize() const { return size; }
 
+    /// @brief objectId of the box when existing
     void setId(int id) { this->id = id; }
     int getId() const { return id; }
 
+    /// @brief sorting key for directory listing
     void setSortKey(std::string sortKey) { this->sortKey = std::move(sortKey); }
     std::string getSortKey() const { return sortKey; }
 
 protected:
-    /// \brief key for the box to be referenced in layouts
+    /// @brief key for the box to be referenced in layouts
     std::string key;
-    /// \brief title string for the box
+    /// @brief title string for the box
     std::string title;
-    /// \brief object class to be used for new containers
+    /// @brief object class to be used for new containers
     std::string objClass;
-    /// \brief shortcut name for upnp shortcuts list
+    /// @brief shortcut name for upnp shortcuts list
     std::string upnpShortcut;
-    /// \brief sorting key for directory listing
+    /// @brief sorting key for directory listing
     std::string sortKey;
-    /// \brief allow to disable boxes
+    /// @brief allow to disable boxes
     bool enabled { true };
-    /// \brief size value for the box, esp. in structured layout
+    /// @brief allow to search for boxes
+    bool searchable { true };
+    /// @brief size value for the box, esp. in structured layout
     int size { 1 };
-    /// \brief objectId of the box when existing
+    /// @brief objectId of the box when existing
     int id { INVALID_OBJECT_ID };
 };
 
@@ -195,10 +235,10 @@ public:
     AutoscanMediaMode getType() const { return type; }
     void setType(AutoscanMediaMode type) { this->type = type; }
 
-    /// \brief comparison of chains
+    /// @brief comparison of chains
     bool equals(const std::shared_ptr<BoxChain>& other) { return this->type == other->type && this->index == other->index; }
 
-    /// \brief links for chain
+    /// @brief links for chain
     std::vector<std::vector<std::pair<std::string, std::string>>> getLinks(bool edit = false) const { return this->links.getVectorOption(edit); }
     std::size_t getLinksSize(bool edit = false) const { return this->links.getVectorOption(edit).size(); }
     void setLinks(const std::vector<std::vector<std::pair<std::string, std::string>>>& links) { this->links = VectorOption(links); }
@@ -208,9 +248,9 @@ public:
 protected:
     /// @brief identification of chains
     std::size_t index = { 0 };
-    /// \brief media type chain applies to
+    /// @brief media type chain applies to
     AutoscanMediaMode type;
-    /// \brief list of chain links making up the virtual tree
+    /// @brief list of chain links making up the virtual tree
     VectorOption links;
 };
 
