@@ -21,8 +21,8 @@
     $Id$
 */
 
-/// \file config_setup_path.h
-/// \brief Definitions of the ConfigPathSetup class.
+/// @file config/setup/config_setup_path.h
+/// @brief Definitions of the ConfigPathSetup class.
 
 #ifndef __CONFIG_SETUP_PATH_H__
 #define __CONFIG_SETUP_PATH_H__
@@ -31,15 +31,15 @@
 
 enum class ConfigPathArguments {
     none = 0,
-    /// \brief isFile file or directory
+    /// @brief isFile file or directory
     isFile = (1 << 0),
-    /// \brief file/directory must exist
+    /// @brief file/directory must exist
     mustExist = (1 << 1),
-    /// \brief option must not be empty
+    /// @brief option must not be empty
     notEmpty = (1 << 2),
-    /// \brief file has to be executable
+    /// @brief file has to be executable
     isExe = (1 << 3),
-    /// \brief path can be empty
+    /// @brief path can be empty
     resolveEmpty = (1 << 4),
 };
 
@@ -56,8 +56,8 @@ inline ConfigPathArguments operator&(ConfigPathArguments a, ConfigPathArguments
 class ConfigPathSetup : public ConfigSetup {
 protected:
     ConfigPathArguments arguments;
-    /// \brief resolve path against home, an exception is raised if path does not exist on filesystem.
-    /// \param path path to be resolved
+    /// @brief resolve path against home, an exception is raised if path does not exist on filesystem.
+    /// @param path path to be resolved
     fs::path resolvePath(fs::path path) const;
 
     void loadArguments(const std::map<std::string, std::string>* arguments = nullptr);
@@ -68,7 +68,12 @@ protected:
 public:
     static fs::path Home;
 
-    ConfigPathSetup(ConfigVal option, const char* xpath, const char* help, const char* defaultValue = "", ConfigPathArguments arguments = ConfigPathArguments::mustExist | ConfigPathArguments::resolveEmpty)
+    ConfigPathSetup(
+        ConfigVal option,
+        const char* xpath,
+        const char* help,
+        const char* defaultValue = "",
+        ConfigPathArguments arguments = ConfigPathArguments::mustExist | ConfigPathArguments::resolveEmpty)
         : ConfigSetup(option, xpath, help, false, defaultValue)
         , arguments(arguments)
     {
@@ -76,12 +81,21 @@ public:
 
     std::string getTypeString() const override { return "Path"; }
 
-    void makeOption(const pugi::xml_node& root, const std::shared_ptr<Config>& config, const std::map<std::string, std::string>* arguments = nullptr) override;
+    void makeOption(
+        const pugi::xml_node& root,
+        const std::shared_ptr<Config>& config,
+        const std::map<std::string, std::string>* arguments = nullptr) override;
 
-    void makeOption(std::string optValue, const std::shared_ptr<Config>& config, const std::map<std::string, std::string>* arguments = nullptr) override;
+    void makeOption(
+        std::string optValue,
+        const std::shared_ptr<Config>& config,
+        const std::map<std::string, std::string>* arguments = nullptr) override;
 
     std::shared_ptr<ConfigOption> newOption(std::string& optValue);
-    fs::path getXmlContent(const pugi::xml_node& root, bool doResolve = false);
+    fs::path getXmlContent(
+        const pugi::xml_node& root,
+        const std::shared_ptr<Config>& config,
+        bool doResolve = false);
 
     bool checkPathValue(std::string& optValue, std::string& pathValue) const;
 
