@@ -11,6 +11,8 @@
                             Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>,
                             Leonhard Wimmer <leo@mediatomb.cc>
 
+    Copyright (C) 2016-2025 Gerbera Contributors
+
     MediaTomb is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
     as published by the Free Software Foundation.
@@ -27,13 +29,16 @@
     $Id$
 */
 
-/// \file task_processor.cc
+/// @file content/onlineservice/task_processor.cc
 
 #ifdef ONLINE_SERVICES
+#define GRB_LOG_FAC GrbLogFacility::online
 #include "task_processor.h" // API
 
-#include "content/content_manager.h"
+#include "content/content.h"
 #include "content/layout/layout.h"
+#include "exceptions.h"
+#include "online_service.h"
 
 TaskProcessor::TaskProcessor(std::shared_ptr<Config> config)
     : config(std::move(config))
@@ -158,14 +163,14 @@ std::deque<std::shared_ptr<GenericTask>> TaskProcessor::getTasklist() const
     return taskList;
 }
 
-TPFetchOnlineContentTask::TPFetchOnlineContentTask(std::shared_ptr<ContentManager> content,
+TPFetchOnlineContentTask::TPFetchOnlineContentTask(std::shared_ptr<Content> content,
     std::shared_ptr<TaskProcessor> taskProcessor,
     std::shared_ptr<Timer> timer,
     std::shared_ptr<OnlineService> service,
     std::shared_ptr<Layout> layout,
     bool cancellable,
     bool unscheduledRefresh)
-    : GenericTask(TaskProcessorTask)
+    : GenericTask(TaskOwner::TaskProcessorTask)
     , content(std::move(content))
     , task_processor(std::move(taskProcessor))
     , timer(std::move(timer))
@@ -174,7 +179,7 @@ TPFetchOnlineContentTask::TPFetchOnlineContentTask(std::shared_ptr<ContentManage
     , unscheduled_refresh(unscheduledRefresh)
 {
     this->cancellable = cancellable;
-    this->taskType = FetchOnlineContent;
+    this->taskType = TaskType::FetchOnlineContent;
 }
 
 void TPFetchOnlineContentTask::run()
@@ -185,7 +190,6 @@ void TPFetchOnlineContentTask::run()
     }
 
     try {
-        // cm->_fetchOnlineContent(service, getParentID(), unscheduled_refresh);
         if (service->refreshServiceData(layout) && (isValid())) {
             log_debug("Scheduling another task for online service: {}", service->getServiceName());
 
