@@ -29,7 +29,7 @@
     $Id$
 */
 
-/// \file playlist_parser_script.cc
+/// @file content/scripting/playlist_parser_script.cc
 
 #ifdef HAVE_JS
 #define GRB_LOG_FAC GrbLogFacility::script
@@ -49,15 +49,9 @@
 #include "util/string_converter.h"
 
 PlaylistParserScript::PlaylistParserScript(const std::shared_ptr<Content>& content, const std::string& parent)
-    : ParserScript(content, parent, "playlist", "playlist", true)
+    : ParserScript(content, parent, "playlist", "pls", true)
 {
-    std::string scriptPath = config->getOption(ConfigVal::IMPORT_SCRIPTING_PLAYLIST_SCRIPT);
-    if (!scriptPath.empty()) {
-        load(scriptPath);
-        scriptMode = true;
-    } else {
-        playlistFunction = config->getOption(ConfigVal::IMPORT_SCRIPTING_IMPORT_FUNCTION_PLAYLIST);
-    }
+    playlistFunction = config->getOption(ConfigVal::IMPORT_SCRIPTING_IMPORT_FUNCTION_PLAYLIST);
 }
 
 std::pair<std::shared_ptr<CdsObject>, int> PlaylistParserScript::createObject2cdsObject(
@@ -115,7 +109,7 @@ bool PlaylistParserScript::setRefId(const std::shared_ptr<CdsObject>& cdsObj, co
             cdsObj->setRefID(pcdId);
             cdsObj->setFlag(OBJECT_FLAG_USE_RESOURCE_REF);
         }
-    } else if (config->getBoolOption(ConfigVal::IMPORT_SCRIPTING_PLAYLIST_SCRIPT_LINK_OBJECTS) || config->getBoolOption(ConfigVal::IMPORT_SCRIPTING_PLAYLIST_LINK_OBJECTS)) {
+    } else if (config->getBoolOption(ConfigVal::IMPORT_SCRIPTING_PLAYLIST_LINK_OBJECTS)) {
         cdsObj->setFlag(OBJECT_FLAG_PLAYLIST_REF);
         cdsObj->setRefID(origObject->getID());
     }
@@ -124,7 +118,7 @@ bool PlaylistParserScript::setRefId(const std::shared_ptr<CdsObject>& cdsObj, co
 
 void PlaylistParserScript::handleObject2cdsContainer(duk_context* ctx, const std::shared_ptr<CdsObject>& pcd, const std::shared_ptr<CdsContainer>& cont)
 {
-    if ((config->getBoolOption(ConfigVal::IMPORT_SCRIPTING_PLAYLIST_SCRIPT_LINK_OBJECTS) || config->getBoolOption(ConfigVal::IMPORT_SCRIPTING_PLAYLIST_LINK_OBJECTS)) && cont->getRefID() > 0) {
+    if (config->getBoolOption(ConfigVal::IMPORT_SCRIPTING_PLAYLIST_LINK_OBJECTS) && cont->getRefID() > 0) {
         cont->setFlag(OBJECT_FLAG_PLAYLIST_REF);
     }
 }
@@ -197,17 +191,8 @@ void PlaylistParserScript::processPlaylistObject(
 
     ScriptingRuntime::AutoLock lock(runtime->getMutex());
     try {
-        if (scriptMode) {
-            execute(obj, rootPath);
-        } else {
-            call(obj, nullptr, playlistFunction, rootPath, "");
-        }
+        call(obj, nullptr, playlistFunction, rootPath, "");
     } catch (const std::runtime_error&) {
-        if (scriptMode) {
-            cleanup();
-            duk_pop(ctx);
-        }
-
         currentHandle = nullptr;
 
         delete[] currentLine;
