@@ -29,7 +29,7 @@
     $Id$
 */
 
-/// \file exiv2_handler.cc
+/// @file metadata/exiv2_handler.cc
 
 #ifdef HAVE_EXIV2
 #define GRB_LOG_FAC GrbLogFacility::exiv2
@@ -60,7 +60,7 @@ Exiv2Handler::Exiv2Handler(const std::shared_ptr<Context>& context)
     Exiv2::LogMsg::setHandler([](auto, auto s) { log_debug("Exiv2: {}", s); });
 }
 
-/// \brief Wrapper class to interface with EXIV2
+/// @brief Wrapper class to interface with EXIV2
 class Exiv2Object {
 public:
     std::string location;
@@ -97,7 +97,7 @@ public:
         comment = image->comment();
     }
 
-    /// \brief get date/time
+    /// @brief get date/time
     std::string getDate() const
     {
         std::string value = getKey("Exif.Photo.DateTimeOriginal");
@@ -114,7 +114,7 @@ public:
         return value;
     }
 
-    /// \brief get key value from image
+    /// @brief get key value from image
     std::string getKey(const std::string& key) const
     {
         log_debug("key: {} ", key);
@@ -141,17 +141,27 @@ public:
     }
 };
 
-void Exiv2Handler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
+bool Exiv2Handler::isSupported(
+    const std::string& contentType,
+    bool isOggTheora,
+    const std::string& mimeType,
+    ObjectType mediaType)
+{
+    return mediaType == ObjectType::Image;
+}
+
+bool Exiv2Handler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
 {
     auto item = std::dynamic_pointer_cast<CdsItem>(obj);
     if (!item || !isEnabled)
-        return;
+        return false;
 
+    bool result = true;
     try {
         Exiv2Object exivObj(converterManager, item);
         if (exivObj.exifData->empty()) {
             // no exiv2 record found in image
-            return;
+            return false;
         }
 
         auto date = exivObj.getDate();
@@ -216,11 +226,14 @@ void Exiv2Handler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
         }
     } catch (const Exiv2::AnyError& ex) {
         log_warning("Caught Exiv2 exception processing {}: '{}'", item->getLocation().string(), ex.what());
+        result = false;
     } catch (const std::runtime_error& e) {
         log_warning("Caught exception processing {}: '{}'", item->getLocation().string(), e.what());
+        result = false;
     }
 
     Exiv2::XmpProperties::unregisterNs();
+    return result;
 }
 
 std::unique_ptr<IOHandler> Exiv2Handler::serveContent(
