@@ -29,7 +29,7 @@
     $Id$
 */
 
-/// \file libexif_handler.cc
+/// @file metadata/libexif_handler.cc
 
 #ifdef HAVE_LIBEXIF
 #define GRB_LOG_FAC GrbLogFacility::exif
@@ -46,7 +46,7 @@
 
 #include <array>
 
-/// \brief Sets resolution for a given resource index, item must be a JPEG image
+/// @brief Sets resolution for a given resource index, item must be a JPEG image
 static void setJpegResolutionResource(
     const std::shared_ptr<CdsItem>& item,
     std::size_t resNum = 0)
@@ -191,6 +191,7 @@ static void logfunc(ExifLog* log, ExifLogCode code, const char* domain, const ch
     std::vsnprintf(buf.data(), len + 1, format, args);
     std::string message = buf.data();
     log_debug("Exif: {}-{}, domain {}: {}", exif_log_code_get_title(code), exif_log_code_get_message(code), domain, message);
+    va_end(args_copy);
 }
 
 LibExifHandler::LibExifHandler(const std::shared_ptr<Context>& context)
@@ -210,7 +211,7 @@ LibExifHandler::~LibExifHandler()
     exif_log_free(log);
 }
 
-/// \brief Wrapper class to interface with LibExif
+/// @brief Wrapper class to interface with LibExif
 class LibExifObject {
 private:
     static constexpr std::size_t BUFLEN = 4096;
@@ -236,12 +237,15 @@ public:
             exif_data_unref(exifData);
     }
 
-    /// \brief check if libexif information is available
+    LibExifObject(const LibExifObject&) = delete;
+    LibExifObject& operator=(const LibExifObject&) = delete;
+
+    /// @brief check if libexif information is available
     operator bool() const
     {
         return exifData;
     }
-    /// \brief check if thumbnail information is available
+    /// @brief check if thumbnail information is available
     bool hasThumb() const
     {
         return exifData && exifData->size > 0U;
@@ -260,7 +264,7 @@ public:
         return std::make_unique<MemIOHandler>(exifData->data, exifData->size);
     }
 
-    /// \brief get date/time
+    /// @brief get date/time
     std::string getDate(ExifEntry* entry)
     {
         auto value = trimString(exif_egv(entry));
@@ -282,7 +286,7 @@ public:
         return "";
     }
 
-    /// \brief get key value from image
+    /// @brief get key value from image
     std::string getKey(ExifEntry* entry)
     {
         auto value = trimString(exif_egv(entry));
@@ -297,7 +301,7 @@ public:
         return "";
     }
 
-    /// \brief get resolution for thumbnail
+    /// @brief get resolution for thumbnail
     std::string getThumbResolution()
     {
         try {
@@ -313,6 +317,15 @@ public:
     }
 };
 
+bool LibExifHandler::isSupported(
+    const std::string& contentType,
+    bool isOggTheora,
+    const std::string& mimeType,
+    ObjectType mediaType)
+{
+    return contentType == CONTENT_TYPE_JPG;
+}
+
 void LibExifHandler::process_ifd(
     const ExifContent* content,
     const std::shared_ptr<CdsItem>& item,
@@ -411,18 +424,18 @@ void LibExifHandler::process_ifd(
     }
 }
 
-void LibExifHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
+bool LibExifHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
 {
     auto item = std::dynamic_pointer_cast<CdsItem>(obj);
     if (!item || !isEnabled)
-        return;
+        return false;
 
     LibExifObject exifObject(converterManager, item);
 
     if (!exifObject) {
         log_debug("Exif data not found, attempting to set resolution internally...");
         setJpegResolutionResource(item);
-        return;
+        return true;
     }
 
     // image resolution in pixels
@@ -461,6 +474,7 @@ void LibExifHandler::fillMetadata(const std::shared_ptr<CdsObject>& obj)
         if (!resolution.empty())
             resource->addAttribute(ResourceAttribute::RESOLUTION, resolution);
     }
+    return true;
 }
 
 std::unique_ptr<IOHandler> LibExifHandler::serveContent(
