@@ -21,7 +21,7 @@
     $Id$
 */
 
-/// \file matroska_handler.cc
+/// @file metadata/matroska_handler.cc
 
 #ifdef HAVE_MATROSKA
 #define GRB_LOG_FAC GrbLogFacility::matroska
@@ -55,7 +55,7 @@
 using namespace libebml;
 using namespace libmatroska;
 
-// file managment
+/// @brief file management for matroska
 class FileIOCallback : public IOCallback {
 private:
     GrbFile file;
@@ -69,7 +69,7 @@ public:
     }
 
 #if LIBMATROSKA_VERSION < 0x020000
-    uint32
+    uint32_t
 #else
     std::size_t
 #endif
@@ -333,6 +333,7 @@ void MatroskaHandler::parseHead(
     delete ebmlHead;
 }
 
+/// @brief wrapper object for matroska files
 class MkvObject {
 public:
     std::string location;
