@@ -24,10 +24,10 @@
 #include "cds/cds_container.h"
 #include "cds/cds_item.h"
 #include "common.h"
-#include "config/result/client_config.h"
-#include "config/result/transcoding.h"
 #include "config/config_definition.h"
 #include "config/config_setup.h"
+#include "config/result/client_config.h"
+#include "config/result/transcoding.h"
 #include "context.h"
 #include "metadata/metadata_handler.h"
 #include "upnp/client_manager.h"
@@ -80,6 +80,51 @@ public:
     std::shared_ptr<DatabaseMock> database;
     std::shared_ptr<Context> context;
     std::shared_ptr<ConverterManager> converterManager;
+
+    std::shared_ptr<CdsObject> makeObjectWithRes()
+    {
+        auto obj = std::make_shared<CdsItem>();
+        obj->setID(42);
+        obj->setParentID(2);
+        obj->setRestricted(false);
+        obj->setTitle("Title");
+        obj->setClass(UPNP_CLASS_MUSIC_TRACK);
+        obj->addMetaData(MetadataFields::M_DESCRIPTION, "Description");
+        obj->addMetaData(MetadataFields::M_ALBUM, "Album");
+        obj->addMetaData(MetadataFields::M_TRACKNUMBER, "7");
+        obj->addMetaData(MetadataFields::M_UPNP_DATE, "2002-01-01");
+        obj->addMetaData(MetadataFields::M_DATE, "2022-04-01T00:00:00");
+
+        auto resource = std::make_shared<CdsResource>(ContentHandler::DEFAULT, ResourcePurpose::Content);
+        resource->addAttribute(ResourceAttribute::PROTOCOLINFO, "http-get:*:audio/mpeg:*");
+        resource->addAttribute(ResourceAttribute::BITRATE, "16044");
+        resource->addAttribute(ResourceAttribute::DURATION, "123456");
+        resource->addAttribute(ResourceAttribute::NRAUDIOCHANNELS, "2");
+        resource->addAttribute(ResourceAttribute::SIZE, "4711");
+        obj->addResource(resource);
+
+        resource = std::make_shared<CdsResource>(ContentHandler::SUBTITLE, ResourcePurpose::Subtitle);
+        std::string type = "srt";
+        resource->addAttribute(ResourceAttribute::PROTOCOLINFO, renderProtocolInfo("text/" + type));
+        resource->addAttribute(ResourceAttribute::RESOURCE_FILE, "/home/resource/subtitle.srt");
+        resource->addParameter("type", type);
+        obj->addResource(resource);
+
+        resource = std::make_shared<CdsResource>(ContentHandler::SUBTITLE, ResourcePurpose::Subtitle);
+        resource->addAttribute(ResourceAttribute::PROTOCOLINFO, renderProtocolInfo("text/" + type));
+        resource->addAttribute(ResourceAttribute::RESOURCE_FILE, "/home/resource/subtitle.srt");
+        resource->addAttribute(ResourceAttribute::LANGUAGE, "fr");
+        resource->addParameter("type", type);
+        obj->addResource(resource);
+
+        resource = std::make_shared<CdsResource>(ContentHandler::FANART, ResourcePurpose::Thumbnail);
+        resource->addAttribute(ResourceAttribute::PROTOCOLINFO, renderProtocolInfo("image/jpeg"));
+        resource->addAttribute(ResourceAttribute::RESOURCE_FILE, "/home/resource/cover.jpg");
+        resource->addAttribute(ResourceAttribute::RESOLUTION, "200x200");
+        obj->addResource(resource);
+
+        return obj;
+    }
 };
 
 TEST_F(UpnpXmlTest, RenderObjectContainer)
@@ -191,9 +236,9 @@ TEST_F(UpnpXmlTest, RenderObjectItemWithEscapes)
     obj->addMetaData(MetadataFields::M_DATE, "2022-04-01T00:00:00");
 
     auto clientConfig = std::make_shared<MyConfigMock>();
-    auto clientManager = std::make_shared<ClientManager>(clientConfig, database);
+    auto clientManager = std::make_shared<ClientManager>(clientConfig, database, nullptr);
     auto addr = std::make_shared<GrbNet>("192.168.99.100");
-    auto quirks = std::make_shared<Quirks>(subject, clientManager, addr, "DLNADOC/1.50");
+    auto quirks = std::make_shared<Quirks>(subject, clientManager, addr, "DLNADOC/1.50", nullptr);
 
     std::ostringstream expectedXml;
     expectedXml << "<DIDL-Lite>\n";
@@ -238,9 +283,9 @@ TEST_F(UpnpXmlTest, RenderObjectItemWithStrictXmlQuirks)
     obj->addMetaData(MetadataFields::M_DATE, "2022-04-01T00:00:00");
 
     auto clientConfig = std::make_shared<MyConfigMock>();
-    auto clientManager = std::make_shared<ClientManager>(clientConfig, database);
+    auto clientManager = std::make_shared<ClientManager>(clientConfig, database, nullptr);
     auto addr = std::make_shared<GrbNet>("192.168.99.100");
-    auto quirks = std::make_shared<Quirks>(subject, clientManager, addr, "Allegro-Software-WebClient/5.40b1 DLNADOC/1.50");
+    auto quirks = std::make_shared<Quirks>(subject, clientManager, addr, "Allegro-Software-WebClient/5.40b1 DLNADOC/1.50", nullptr);
 
     std::ostringstream expectedXml;
     expectedXml << "<DIDL-Lite>\n";
@@ -273,45 +318,46 @@ TEST_F(UpnpXmlTest, RenderObjectItemWithResources)
     // arrange
     pugi::xml_document didlLite;
     auto root = didlLite.append_child("DIDL-Lite");
-    auto obj = std::make_shared<CdsItem>();
-    obj->setID(42);
-    obj->setParentID(2);
-    obj->setRestricted(false);
-    obj->setTitle("Title");
-    obj->setClass(UPNP_CLASS_MUSIC_TRACK);
-    obj->addMetaData(MetadataFields::M_DESCRIPTION, "Description");
-    obj->addMetaData(MetadataFields::M_ALBUM, "Album");
-    obj->addMetaData(MetadataFields::M_TRACKNUMBER, "7");
-    obj->addMetaData(MetadataFields::M_UPNP_DATE, "2002-01-01");
-    obj->addMetaData(MetadataFields::M_DATE, "2022-04-01T00:00:00");
+    auto obj = makeObjectWithRes();
 
-    auto resource = std::make_shared<CdsResource>(ContentHandler::DEFAULT, ResourcePurpose::Content);
-    resource->addAttribute(ResourceAttribute::PROTOCOLINFO, "http-get:*:audio/mpeg:*");
-    resource->addAttribute(ResourceAttribute::BITRATE, "16044");
-    resource->addAttribute(ResourceAttribute::DURATION, "123456");
-    resource->addAttribute(ResourceAttribute::NRAUDIOCHANNELS, "2");
-    resource->addAttribute(ResourceAttribute::SIZE, "4711");
-    obj->addResource(resource);
+    std::ostringstream expectedXml;
+    expectedXml << "<DIDL-Lite>\n";
+    expectedXml << "<item id=\"42\" parentID=\"2\" restricted=\"0\">\n";
+    expectedXml << "<dc:title>Title</dc:title>\n";
+    expectedXml << "<upnp:class>object.item.audioItem.musicTrack</upnp:class>\n";
+    expectedXml << "<dc:date>2022-04-01T00:00:00</dc:date>\n";
+    expectedXml << "<dc:description>Description</dc:description>\n";
+    expectedXml << "<upnp:album>Album</upnp:album>\n";
+    expectedXml << "<upnp:date>2002-01-01</upnp:date>\n";
+    expectedXml << "<upnp:originalTrackNumber>7</upnp:originalTrackNumber>\n";
+    expectedXml << "<upnp:albumArtURI xmlns:dlna=\"urn:schemas-dlna-org:metadata-1-0\" dlna:profileID=\"JPEG_TN\">http://server/media/object_id/42/res_id/3/ext/file.jpg</upnp:albumArtURI>\n";
+    expectedXml << "<sec:CaptionInfoEx sec:type=\"srt\">http://server/media/object_id/42/res_id/1/type/srt/ext/file.srt</sec:CaptionInfoEx>\n";
+    expectedXml << "<res id=\"42.0\" size=\"4711\" duration=\"123456\" bitrate=\"16044\" nrAudioChannels=\"2\" protocolInfo=\"http-get:*:audio/mpeg:DLNA.ORG_PN=MP3;DLNA.ORG_OP=01;DLNA.ORG_CI=0;DLNA.ORG_FLAGS=01700000000000000000000000000000\">http://server/media/object_id/42/res_id/0/group/default/ext/file.mp3</res>\n";
+    expectedXml << "<res id=\"42.1\" protocolInfo=\"http-get:*:text/srt:DLNA.ORG_OP=01;DLNA.ORG_CI=0;DLNA.ORG_FLAGS=00d00000000000000000000000000000\">http://server/media/object_id/42/res_id/1/type/srt/ext/file.srt</res>\n";
+    expectedXml << "<res id=\"42.2\" protocolInfo=\"http-get:*:text/srt:DLNA.ORG_OP=01;DLNA.ORG_CI=0;DLNA.ORG_FLAGS=00d00000000000000000000000000000\" dc:language=\"fr\">http://server/media/object_id/42/res_id/2/type/srt/ext/file.fr.srt</res>\n";
+    expectedXml << "<res id=\"42.3\" resolution=\"200x200\" protocolInfo=\"http-get:*:image/jpeg:DLNA.ORG_PN=JPEG_TN;DLNA.ORG_OP=01;DLNA.ORG_CI=0;DLNA.ORG_FLAGS=00800000000000000000000000000000\">http://server/media/object_id/42/res_id/3/ext/file.jpg</res>\n";
+    expectedXml << "</item>\n";
+    expectedXml << "</DIDL-Lite>\n";
 
-    resource = std::make_shared<CdsResource>(ContentHandler::SUBTITLE, ResourcePurpose::Subtitle);
-    std::string type = "srt";
-    resource->addAttribute(ResourceAttribute::PROTOCOLINFO, renderProtocolInfo("text/" + type));
-    resource->addAttribute(ResourceAttribute::RESOURCE_FILE, "/home/resource/subtitle.srt");
-    resource->addParameter("type", type);
-    obj->addResource(resource);
+    EXPECT_CALL(*config, getOption(ConfigVal::IMPORT_LIBOPTS_ENTRY_SEP))
+        .WillRepeatedly(Return(" / "));
+    EXPECT_CALL(*config, getTranscodingProfileListOption(_))
+        .WillRepeatedly(Return(std::make_shared<TranscodingProfileList>()));
 
-    resource = std::make_shared<CdsResource>(ContentHandler::SUBTITLE, ResourcePurpose::Subtitle);
-    resource->addAttribute(ResourceAttribute::PROTOCOLINFO, renderProtocolInfo("text/" + type));
-    resource->addAttribute(ResourceAttribute::RESOURCE_FILE, "/home/resource/subtitle.srt");
-    resource->addAttribute(ResourceAttribute::LANGUAGE, "fr");
-    resource->addParameter("type", type);
-    obj->addResource(resource);
+    // act
+    subject->renderObject(obj, { "*" }, std::string::npos, root);
 
-    resource = std::make_shared<CdsResource>(ContentHandler::FANART, ResourcePurpose::Thumbnail);
-    resource->addAttribute(ResourceAttribute::PROTOCOLINFO, renderProtocolInfo("image/jpeg"));
-    resource->addAttribute(ResourceAttribute::RESOURCE_FILE, "/home/resource/cover.jpg");
-    resource->addAttribute(ResourceAttribute::RESOLUTION, "200x200");
-    obj->addResource(resource);
+    // assert
+    std::string didlLiteXml = UpnpXMLBuilder::printXml(didlLite, "");
+    EXPECT_STREQ(didlLiteXml.c_str(), expectedXml.str().c_str());
+}
+
+TEST_F(UpnpXmlTest, RenderObjectItemWithResourcesWithQuirks)
+{
+    // arrange
+    pugi::xml_document didlLite;
+    auto root = didlLite.append_child("DIDL-Lite");
+    auto obj = makeObjectWithRes();
 
     std::ostringstream expectedXml;
     expectedXml << "<DIDL-Lite>\n";
@@ -337,8 +383,13 @@ TEST_F(UpnpXmlTest, RenderObjectItemWithResources)
     EXPECT_CALL(*config, getTranscodingProfileListOption(_))
         .WillRepeatedly(Return(std::make_shared<TranscodingProfileList>()));
 
+    ClientProfile pInfo;
+    pInfo.flags = QUIRK_FLAG_CAPTION_PROTOCOL;
+    auto addr = std::make_shared<GrbNet>("127.0.0.1");
+    struct ClientObservation client(addr, "ua", std::chrono::seconds(0), std::chrono::seconds(0), nullptr, &pInfo);
+    auto quirks = std::make_shared<Quirks>(&client);
     // act
-    subject->renderObject(obj, { "*" }, std::string::npos, root);
+    subject->renderObject(obj, { "*" }, std::string::npos, root, quirks);
 
     // assert
     std::string didlLiteXml = UpnpXMLBuilder::printXml(didlLite, "");
@@ -400,12 +451,11 @@ TEST_F(UpnpXmlTest, FirstResourceRendersPureWhenExternalUrl)
     EXPECT_STREQ(result.c_str(), "http://localhost/external/url");
 }
 
-TEST_F(UpnpXmlTest, FirstResourceAddsLocalResourceIdToExternalUrlWhenOnlineWithProxy)
+TEST_F(UpnpXmlTest, FirstResourceAddsLocalResourceIdToExternalUrlWhenWithProxy)
 {
     auto obj = std::make_shared<CdsItemExternalURL>();
     obj->setLocation("http://localhost/external/url");
     obj->setID(12345);
-    obj->setFlag(OBJECT_FLAG_ONLINE_SERVICE);
     obj->setFlag(OBJECT_FLAG_PROXY_URL);
 
     auto resource = std::make_shared<CdsResource>(ContentHandler::DEFAULT, ResourcePurpose::Content);
